@@ -30,8 +30,8 @@ class getStripe:
         self.chromsizes = chromsizes
         self.core = core
         self.chromnames2sizes={}
-        for i in range(len(self.chromnames)):
-            self.chromnames2sizes[self.chromnames[i]] = self.chromsizes[i]
+        for i in range(len(self.all_chromnames)):
+            self.chromnames2sizes[self.all_chromnames[i]] = self.all_chromsizes[i]
 
     def nulldist(self):
         np.seterr(divide='ignore', invalid='ignore')
@@ -49,6 +49,7 @@ class getStripe:
         samplesize[0] += dif
 
         def available_cols(chr):
+            np.seterr(divide='ignore', invalid='ignore')
             chr = str(chr)
             chrsize = self.chromnames2sizes[chr]
             itera = min(chrsize/self.resol/500, 25)
@@ -208,9 +209,12 @@ class getStripe:
         bgleft = np.zeros((400,0))
         bgright = np.zeros((400,0))
         for i in range(len(result)):
-            bl,br = result[i]
-            bgleft=np.column_stack((bgleft,bl))
-            bgright=np.column_stack((bgright,br))
+            if(type(result[i]) == type(None)):
+                continue
+            else:
+                bl,br = result[i]
+                bgleft=np.column_stack((bgleft,bl))
+                bgright=np.column_stack((bgright,br))
 
         print('Elapsed time for background estimation: ' + str(np.round((time.time() - t_background_start) / 60, 3)) + ' min')
         return bgleft, bgright
@@ -264,6 +268,8 @@ class getStripe:
                     difference = j
                 elif x2 == y2:  # upward stripe
                     difference = y2 - y1 - j
+                if difference >= 400:
+                    difference = 399
                 difference = int(difference)
                 bleft = bgleft[difference, :]
                 bright = bgright[difference, :]
@@ -822,6 +828,37 @@ class getStripe:
         result = df.iloc[idx]
         return result
 
+    def selectColumn(self, df):
+        list_chr = df['chr']
+        list_pos1 = df['pos1'].tolist()
+        list_pos2 = df['pos2'].tolist()
+        list_pos3 = df['pos3'].tolist()
+        list_pos4 = df['pos4'].tolist()
+
+        if str(list_chr[0])[0] != 'c':
+            if self.chromnames[0][0] == 'c':
+                list_chr = ['chr'+str(x) for x in list_chr]
+        MAX_POS=[]
+        nrow = df.shape[0]
+        for i in range(nrow):
+            chr = list_chr[i]
+            pos1 = list_pos1[i]
+            pos2 = list_pos2[i]
+            pos3 = list_pos3[i]
+            pos4 = list_pos4[i]
+
+            x_str = str(chr)+':'+str(pos1)+'-'+str(pos2)
+            y_str = str(chr)+':'+str(pos3)+'-'+str(pos4)
+            mat = self.unbalLib.fetch(x_str,y_str)
+            average = np.mean(mat,axis=1)
+            which_max = np.argmax(average)
+            max_pos = pos1 + self.resol * which_max
+            MAX_POS.append(max_pos)
+
+
+        return MAX_POS
+
+
 def nantozero(nparray):
     where_are_nans = np.isnan(nparray)
     nparray[where_are_nans] = 0
